summaryrefslogtreecommitdiffstats
path: root/common/paths/pathparser.go
diff options
context:
space:
mode:
Diffstat (limited to 'common/paths/pathparser.go')
-rw-r--r--common/paths/pathparser.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/common/paths/pathparser.go b/common/paths/pathparser.go
index 897edb9b7..f506eb60f 100644
--- a/common/paths/pathparser.go
+++ b/common/paths/pathparser.go
@@ -359,8 +359,8 @@ func (p *Path) Path() (d string) {
return p.norm(p.s)
}
-// Unmormalized returns the Path with the original case preserved.
-func (p *Path) Unmormalized() *Path {
+// Unnormalized returns the Path with the original case preserved.
+func (p *Path) Unnormalized() *Path {
return p.unnormalized
}